;**************************************************************************
;* FileName	: TMRX.INC
;* Date 	: 07.10.2003
;* File version : v1.00
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: function for TMRx module
;*		  ==================================
;*		  TMR1_startw
;*		  TMR2_startw
;*
;*
;*-------------------------------------------------------------------------
;* Needed defines and includes in main-modul:
;* 
;* xtal_freq		EQU	4000000	  	; crystal frequency
;* core_freq		EQU	xtal_freq/4	; core operating frequency
;*
;*-------------------------------------------------------------------------
;* Other possible defines in main-modul:
;*
;* #define DEBUG			; for some debug message
;* #define NO_DELAY			; for fast simulation 
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  07/10/2003 	Initial Release
;*
;**************************************************************************

;***** VARIABLES **********************************************************

#ifdef	TMR1_STARTW_INC
	cblock
	  tmr1hi
	endc
#endif

#ifdef	TMR2_STARTW_INC
	cblock
	  tmr2hi
	endc
#endif



;***** TMR1_startw ********************************************************
;* start TMR1
;* Input : w			; timeout value (tmr1hi:w * resolution) uS
;*         tmr1hi		; the most significat bits of timeout (0 .. 255)
;* Output: -			;
;* Clock : 		
;**************************************************************************
#ifdef TMR1_STARTW_INC
TMR1_startw	bcf	T1CON, TMR1ON
		movwf	TMR1L

		comf	tmr1hi,w		; TMR1H:TMR1L = - tmr1hi:w
		movwf	TMR1H
		comf	TMR1L,f
		incf	TMR1L,f
		skipnz
		  incf	TMR1H,f

		bcf	PIR1, TMR1IF
		bsf	T1CON, TMR1ON
		return
#endif



;***** TMR2_startw ********************************************************
;* start TMR2
;* Input : w			; timeout value (tmr2hi:w * resolution) uS
;*         tmr2hi		; the most significat bits of timeout (0 .. 15)
;* Output: -			;
;* Clock : 		
;**************************************************************************
#ifdef TMR2_STARTW_INC
TMR2_startw	clrf	TMR2
		subwf	TMR2,f
		swapf	tmr2hi,f
		rrf	tmr2hi,w
		swapf	tmr2hi,f
		andlw	01111000b
		iorlw	_tmr2pre | 00000100b
		movwf	T2CON
		bcf	PIR1, TMR2IF
		return
#endif



;**************************************************************************
